# = Type: nginx::site::proxy
#
# Reverse proxy connections to a set of upstream servers.
#
# == Parameters
#
# [*site*]
#   The nginx::site resource this should be applied to. No default.
# [*url*]
#   The source URL to redirect users from. Defaults to the resoure name as
#   a top-level directory.
# [*upstream*]
#   The servers to redirect requests to. This is an array. Defaults to an
#   empty array.
# [*content*]
#   Path to content directory. This is useful if you want nginx to serve
#   static content on behalf of a proxied website. (XXX this is a WIP).
# [*websocket*]
#   Configure the reverse proxy to pass through websocket connections.
#   Defaults to false.
# [*headers*]
#   Additional headers to set on proxied connections. This is a hash where
#   the keys are header names. Defaults to an empty hash.
#
# == References
#
# * http://nginx.org/en/docs/http/websocket.html
# * https://chrislea.com/2013/02/23/proxying-websockets-with-nginx/
# * http://stackoverflow.com/questions/15992145/nginx-1-3-13-reverse-proxy-websockets
#
define nginx::site::proxy
(
	$site = undef,
	$url = "/${title}",
	$upstream = [],
	$content = undef,
	$websockets = false,
	$headers = {}
)
{
	# TODO make sure $site is defined and $upstream isn't empty

	# upstream servers
	concat::fragment {"nginx-${site}-proxy-${title}-upstream":
		target  => "nginx-${site}",
		order   => '02',
		content => template('nginx/proxy-upstream.conf.erb'),
		notify  => Service['nginx']
	}

	# site
	concat::fragment {"nginx-${site}-proxy-${title}-site":
		target  => "nginx-${site}",
		order   => '60',
		content => template('nginx/proxy-site.conf.erb'),
		notify  => Service['nginx']
	}
}
