# = Type: nginx::site::redirect
#
# Create a redirect for a given location. This works using the HTTP status
# code 301, which is the most efficient and correct way to redirect a user.
#
# == Parameters
#
# [*site*]
#   The nginx::site resource this redirect should be applied to. No default.
# [*url*]
#   The source URL to redirect users from. Defaults to the resoure name as
#   a top-level directory.
# [*target*]
#   The target URl to send users to. No default.
#
# == References
#
# * http://wiki.nginx.org/Pitfalls#Taxing_Rewrites
#
define nginx::site::redirect
(
	$site = undef,
	$url = "/${title}",
	$target = undef
)
{
	concat::fragment {"nginx-${site}-redirect-${title}":
		target  => "nginx-${site}",
		order   => '50',
		content => template("nginx/redirect.conf.erb"),
		notify  => Service['nginx']
	}
}
